@@ -6,7 +6,7 @@ from gevent.server import StreamServer
 import kola
 from kola import safe_call, safe_func
 from .connection import Connection
-from .stream import Stream
+from gevent_stream import Stream
 
 
 class Kola(kola.Kola):
